@@ -442,6 +442,9 @@ ags_wave_export_dialog_connect(AgsConnectable *connectable)
 
   wave_export_dialog->flags |= AGS_WAVE_EXPORT_DIALOG_CONNECTED;
 
+  g_signal_connect((GObject *) wave_export_dialog, "delete-event",
+		   G_CALLBACK(ags_wave_export_dialog_delete_event), (gpointer) wave_export_dialog);
+  
   g_signal_connect(G_OBJECT(wave_export_dialog->file_chooser_button), "clicked",
 		   G_CALLBACK(ags_wave_export_dialog_file_chooser_button_callback), wave_export_dialog);
   
@@ -575,10 +578,10 @@ ags_wave_export_dialog_apply(AgsApplicable *applicable)
   end_frame = ((16.0 * end_tact) / (16.0 * delay_factor * bpm / 60.0)) * samplerate + buffer_size;  
 
   if(AGS_IS_AUDIOREC(machine)){
-    gchar *filename;
+    if(filename == NULL){
+      filename = gtk_entry_get_text(AGS_AUDIOREC(machine)->filename);
+    }
     
-    filename = gtk_entry_get_text(AGS_AUDIOREC(machine)->filename);
-  
     ags_audiorec_fast_export(machine,
 			     filename,
 			     start_frame, end_frame);
